function [t,w]=gm_antigaussquadrule_m(a,b,mu0);
%GM_ANTIGAUSSQUADRULE_M computes nodes and weights of the anti-Gauss rule
% using the Matlab QR algorithm 

% Input:
% a and b = elements of the diagonal and subdiagonal of the Jacobi
%          matrix for the orthonormal polynomials associated with the measure
% mu0 = moment of order zero
%
% Output:
% t, w = nodes and weights

%
% Author G. Meurant
% June 2007
% Updated July 2015
%

n = length(a);

if n == 1
  t = a(1);
  w = mu0;
  return
end

% modify the last element of b to obtain the Anti-Gauss rule
% from the Gauss Jacobi matrix
b(n-1) = sqrt(2) * b(n-1);

% modified Jacobi matrix
J = diag(a) + diag(b,-1) + diag(b,1); 
J = full(J);
% Eigenvalues and eigenvectors
[V,D] = eig(J);
% nodes
t = diag(D);
[t,i] = sort(t);
% weights
w = mu0 * V(1,i).^2;

t = t';

