function [xw,nloop]=gm_radau_gw(N,ab,end0)
%GM_RADAU_GW Gauss-Radau quadrature rule

% Input:
% N = cardinality of the rule
%     if N is odd, ab must be computed with N+1 nodes
% ab = 3-term recurrence for the monic orthogonal polynomials
%      same as in Gautschi's OPQ
%      ab(1,2) is the 0th moment
% end0 = prescribed node

% Caution: this is not the recurrence coefficients generated by
% gm_classicorthopoly. Use gm_r_jacobi instead

% Output:
% xw = nodes (xw(:,1)) and weights (xw(:,2))
% nloop = number of iterations in QR

%
% from W. Gautschi
% Updated by G. Meurant
% July 2015
%

N0 = size(ab,1);
if N0 < N+1
 error('gm_radau_gw: Input array ab too short')
end

ab0 = ab;
p0 = 0;
p1 = 1;
for n = 1:N
 pm1 = p0;
 p0 = p1;
 p1 = (end0 - ab0(n,1)) * p0 - ab0(n,2) * pm1;
end
ab0(N+1,1) = end0 - ab0(N+1,2) * p0 / p1;

a = ones(size(ab0,1),1);
b = -ab0(:,1);
c = ab0(:,2);
mu0 = ab0(1,2);
symm = 1;

[x,w,nloop] = gm_gaussquadrule(a,b,c,mu0,symm);
xw = [x' w'];



